### Name: elrm
### Title: elrm: exact-like inference in logistic regression models
### Aliases: elrm
### Keywords: methods

### ** Examples

# Drug dataset example with sex and treatment as the variables of interest
data(drugDat);
drug.elrm=elrm(formula=recovered/n~sex+treatment,interest=~sex+treatment,r=4,iter=100000,burnIn=1000,dataset=drugDat);

## Not run: 
##D # crash dataset example where the terms of interest are age and the interaction of age and velocity.
##D data(crashDat);
##D # The following call produces the error message shown below.
##D crash.elrm = elrm(formula=y/n~vel+age+acl+age:vel, interest=~age+age:vel, r=4, iter=5000, dataset=crash, burnIn=100);
##D 
##D # Error in getDesignMatrix(formula, interest, dataset = dataset) : 
##D #        the 'term.labels' attribute of 'terms.formula(interest)' must match those found in 'terms.formula(formula)'
##D 
##D # The error occurs, because the variables within the interaction term in a formula are re-ordered by the ordering in which the variables occur.
##D # Thus, the interaction between age and velocity is labeled as vel:age in the 'formula' model and as age:vel in the 'interest' model.
##D 
##D attr(terms.formula(y/n~vel+age+acl+age:vel),"term.labels");
##D # [1] "vel"     "age"     "acl"     "vel:age"
##D 
##D attr(terms.formula(~age+age:vel),"term.labels");
##D # [1] "age"     "age:vel"
##D 
##D # To get around this problem, place age before vel in the 'formula' model.
##D crash.elrm = elrm(formula=y/n~age+vel+acl+age:vel, interest=~age+age:vel, r=4, iter=5000, dataset=crash, burnIn=100);
## End(Not run)

## Not run: 
##D # Urinary tract dataset example with dia as the variable of interest
##D data(utiDat); 
##D uti.elrm=elrm(uti/n~age+current+dia+oc+pastyr+vi+vic+vicl+vis,interest=~dia,r=4,iter=30000,burnIn=1000,dataset=utiDat);
## End(Not run)

## Not run: 
##D # Titanic dataset example where the variable of interest, class, is coded as a factor
##D data(titanDat); 
##D titanic.elrm=elrm(surv/n~as.factor(class)+age+sex,interest=~as.factor(class),r=4,iter=50000,burnIn=1000,dataset=titanDat);
## End(Not run)



